//
//  PhotoViewController.swift
//  PhotoAlbumDemo01
//
//  Created by 张延深 on 2016/6/20.
//  Copyright © 2016年 宜信. All rights reserved.
//  某个group中的照片列表

import UIKit
import AssetsLibrary

class CEPhotoViewController: UIViewController, UICollectionViewDelegateFlowLayout, UICollectionViewDataSource, UICollectionViewDelegate {
    
    @IBOutlet weak var collectionView: UICollectionView!
    
    var group: ALAssetsGroup!
    
    var photos: NSMutableArray = NSMutableArray() // 存放所有照片
    var selectedPhotos: NSMutableArray = NSMutableArray() // 存放已经选中的照片
    
    // MARK: - Lifecycle
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // 设置标题
        self.title = group.valueForProperty(ALAssetsGroupPropertyName) as? String
        // 设置右侧取消按钮
        let dismissButtonItem = UIBarButtonItem(title: "取消", style: .Plain, target: self, action: #selector(self.dismissSelf))
        self.navigationItem.rightBarButtonItem = dismissButtonItem
        // 只留下照片
        let onlyPhotosFilter = ALAssetsFilter.allPhotos()
        group.setAssetsFilter(onlyPhotosFilter)
        // 遍历照片
        group.enumerateAssetsUsingBlock { (result: ALAsset!, index: Int, stop) in
            
            if result != nil {
                let photoModel = CEPhotoModel()
                photoModel.indexPath = NSIndexPath(forRow: index, inSection: 0)
                photoModel.asset = result
                photoModel.isSelected = false
                self.photos.addObject(photoModel)
            }
        }
    }
    
    override func viewDidAppear(animated: Bool) {
        super.viewDidAppear(animated)
        collectionView.reloadData()
    }
    
    // MARK: - override
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        
        if segue.identifier == "showPhoto" {
            let assets: NSMutableArray = NSMutableArray()
            for tmp in photos {
                let photoModel = tmp as! CEPhotoModel
                assets.addObject(photoModel.asset)
            }
            PageViewControllerData.sharedInstance().photoAssets = assets as [AnyObject]
            let pageViewController = segue.destinationViewController as! MyPageViewController
            let selectedCell = collectionView.indexPathsForSelectedItems()![0]
            pageViewController.startingIndex = selectedCell.row
        }
    }
    
    // MARK: - UICollectionViewDataSource
    
    func collectionView(collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        
        return photos.count
    }
    
    func collectionView(collectionView: UICollectionView, cellForItemAtIndexPath indexPath: NSIndexPath) -> UICollectionViewCell {
        
        let cell = collectionView.dequeueReusableCellWithReuseIdentifier("cell", forIndexPath: indexPath) as! CEPhotoCollectionViewCell
        
        let photoModel = photos[indexPath.row]
        cell.photoModel = photoModel as! CEPhotoModel
        weak var weakSelf = self
        cell.selectPhotoClosure = {
            weakSelf?.selectPhoto(indexPath)
        }
        
        return cell
    }
    
    // MARK: - UICollectionViewDelegate
    
    func collectionView(collectionView: UICollectionView, didSelectItemAtIndexPath indexPath: NSIndexPath) {
        
    }
    
    // MARK: - UICollectionViewDelegateFlowLayout
    
    func collectionView(collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, sizeForItemAtIndexPath indexPath: NSIndexPath) -> CGSize {
        
        let widthOrHeight = (collectionView.frame.width - 25) / 4
        return CGSize(width: widthOrHeight, height: widthOrHeight)
    }
    
    // MARK: - Event response
    
    func dismissSelf() {
        self.dismissViewControllerAnimated(true, completion: nil)
    }
    
    // MARK: - Private methods
    
    private func selectPhoto(indexPath: NSIndexPath) {
        let photoModel = self.photos[indexPath.row] as! CEPhotoModel
        if self.selectedPhotos.count >= 4 && self.selectedPhotos.containsObject(photoModel) == false {
            let alertView = UIAlertView(title: "你最多只能选择4张照片", message: nil, delegate: nil, cancelButtonTitle: "我知道了")
            alertView.show()
        } else {
            photoModel.isSelected = !photoModel.isSelected
            self.collectionView.reloadItemsAtIndexPaths([indexPath])
            
            if photoModel.isSelected {
                self.selectedPhotos.addObject(photoModel)
            } else {
                self.selectedPhotos.removeObject(photoModel)
            }
        }
    }
    
    // MARK: - deinit
    
    deinit {
        debugPrint("CEPhotoViewController释放了！")
    }

}
